#!/usr/bin/env python

'''
HDREfex2.py
call Nik Collection's HDR Efex Pro 2 and pass the active layer(s) as temp file (s).

Author of Original ShellOut Plugin for Windows:
Rob Antonishen

Author of this mod:
Partha Bagchi

Version:
0.6 Made it specific to Nik Collection
0.5 file extension parameter in program list.
0.4 modified to support many optional programs.

this script is modelled after the mm extern LabCurves trace plugin 
by Michael Munzert http://www.mm-log.com/lab-curves-gimp

and thanks to the folks at gimp-chat, has grown a bit ;)

License:

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; version 3 of the License.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

The GNU Public License is available at
http://www.gnu.org/copyleft/gpl.html

'''

from gimpfu import *
import shlex
import subprocess
import os, sys
import tempfile
from shutil import copyfile

	
def gimp_log(text):
    pdb.gimp_message(text)
     
def plugin_main(image, drawable):
  pdb.gimp_image_undo_group_start(image)
  app = "HDR Efex Pro 2.exe"
  BIN_DIR = "C:\\Program Files\\Google\\Nik Collection\\HDR Efex Pro 2"
  appPath = os.path.join( BIN_DIR, app )
  command = [ app ]
  numlayers = len( image.layers )
  for i in range( 0, numlayers):
      filename = "ShellOutTempFile_" + str(i) + ".tif"
      tempfilename = os.path.join(tempfile.gettempdir(), filename )
      pdb.file_png_save_defaults( image, image.layers[i], tempfilename, tempfilename)  
      command.append( tempfilename ) 

  pdb.gimp_progress_set_text ("calling HDR Efex Pro 2 ...")
  pdb.gimp_progress_pulse()
  child = subprocess.check_output( command, executable = appPath )

  # put it as a new layer in the opened image
  try:
    pdb.gimp_message("Reopening HDR image ")
    hdrfile = os.path.expanduser("~/Documents/ShellOutTempFile_0_HDR.tif" )
    newlayer2 = pdb.gimp_file_load_layer( image, hdrfile )
  except:
    pdb.gimp_message("Opening image " + tempfilename + " failed!")
    RuntimeError
  image.add_layer(newlayer2,-1)
  buffer = pdb.gimp_edit_named_copy(newlayer2, "ShellOutTemp")


  # pdb.gimp_buffer_delete(buffer)
  # pdb.gimp_edit_clear(temp)
  # pdb.gimp_floating_sel_anchor(sel)
   
  # cleanup
  for i in range( 0, numlayers):
      filename = "ShellOutTempFile_" + str(i) + ".tif"
      tempfilename = os.path.join(tempfile.gettempdir(), filename )
      os.remove(tempfilename)  # delete the temporary files
  os.remove( hdrfile )     # delete the HDR file create in the User's home folder
  
  # Note the new image is dirty in Gimp and the user will be asked to save before closing.
  pdb.gimp_image_undo_group_end(image)
  gimp.displays_flush()


register(
        "python_fu_HDR_efex_pro",
        "Call HDR Efex Pro 2",
        "Call HDR Efex Pro 2",
        "Partha Bagchi",
        "Copyright 2016 Partha Bagchi",
        "2016",
        "<Image>/Filters/Nik Collection/HDR Efex Pro 2",
        "RGB*, GRAY*",
        [],
        [],
        plugin_main,
        )

main()
